elephant.spike\_train\_generation.NonStationaryPoissonProcess
=============================================================

.. currentmodule:: elephant.spike_train_generation

.. autoclass:: NonStationaryPoissonProcess
   :members:
   :inherited-members:
   :special-members: __call__, __getitem__, __setitem__

   

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NonStationaryPoissonProcess.__init__
      ~NonStationaryPoissonProcess.generate_n_spiketrains
      ~NonStationaryPoissonProcess.generate_spiketrain
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NonStationaryPoissonProcess.t_start
      ~NonStationaryPoissonProcess.t_stop
      ~NonStationaryPoissonProcess.process_operational_time
   
   